#
# spec file for package libpfm
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global python_config CONFIG_PFMLIB_NOPYTHON=y
%bcond_without python2
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define vname   libpfm4
Name:           libpfm
Version:        4.9.0
Release:        lp150.1.5
Summary:        Library to encode performance events
License:        MIT
Group:          Development/Libraries/C and C++
Url:            http://perfmon2.sourceforge.net/
Source:         http://downloads.sourceforge.net/project/perfmon2/libpfm4/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Patch0:         libpfm-python3.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
BuildRequires:  swig >= 2.0.5

%description
This package provides a library that can be used to encode events into the
format required by the operating systems performance monitoring subsystem.

%package -n %{vname}
Summary:        Runtime library to encode performance events for use by perf tool
Group:          System/Libraries

%description -n %{vname}
This package provides a library that can be used to encode events into the
format required by the operating systems performance monitoring subsystem.
The library does not make any performance monitoring system calls, it simply
provides a method to convert an event name, expressed as a string, to an event
encoding. The user of the library may use this event encoding in a subsequent
system call.

The current libpfm4 provides support for the perf_events interface which was
introduced in Linux v2.6.31.

%package        devel
Summary:        Development library to encode performance events for perf_events interface
Group:          Development/Libraries/C and C++
Requires:       %{vname} = %{version}

%description devel
This package provides development libraries and header files used to encode performance events for perf_events interface.

%package        devel-static
Summary:        Static library version of libpfm
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}

%description devel-static
This package contains the static variant of libpfm.

%package -n     python2-%{name}
Summary:        Python bindings for libpfm and perf_event_open system call
Group:          Development/Libraries/Python
Requires:       %{vname} = %{version}

%description -n python2-%{name}
This package provides python bindings for the libpfm4 package and the perf_event_open system call.

%package -n     python3-%{name}
Summary:        Python3 bindings for libpfm and perf_event_open system call
Group:          Development/Libraries/Python
Requires:       %{vname} = %{version}

%description -n python3-%{name}
This package provides python3 bindings for the libpfm4 package and the perf_event_open system call.


%prep
%setup -q
%patch0 -p1
# disable werror
sed -i \
    -e 's:-Werror::g' \
    config.mk

%build
export CFLAGS="%{optflags}"
make %{?_smp_mflags} %{python_config}

pushd python
%python_build
popd

%install
%global python_config %{python_config}
make \
    PREFIX="%{buildroot}/%{_prefix}" \
    LIBDIR="%{buildroot}/%{_libdir}" \
    %{python_config} \
    LDCONFIG=/bin/true \
    install
install -D -p -m 0755 examples/check_events \
  %{buildroot}/%{_bindir}/check_events
install -D -p -m 0755 examples/showevtinfo \
  %{buildroot}/%{_bindir}/showevtinfo
install -D -p -m 0755 perf_examples/evt2raw \
  %{buildroot}/%{_bindir}/evt2raw

pushd python
%python_install
popd

%post -n %{vname} -p /sbin/ldconfig
%postun	-n %{vname} -p /sbin/ldconfig

%files -n %{vname}
%doc README
%{_libdir}/libpfm.so.*

%files devel
%{_includedir}/*
%{_mandir}/man3/*
%{_libdir}/lib*.so
%{_bindir}/check_events
%{_bindir}/showevtinfo
%{_bindir}/evt2raw

%files devel-static
%{_libdir}/lib*.a

%if %{with python2}
%files -n python2-%{name}
%{python2_sitearch}/*
%endif

%files -n python3-%{name}
%{python3_sitearch}/*

%changelog
* Tue Jan 23 2018 tchvatal@suse.com
- Remove useless byte-compiling for py2 that breaks py3 only build
- Update libpfm-python3.patch to fix one stray identation issue
* Wed Jan 17 2018 tchvatal@suse.com
- Add patch to build and work with python3:
  * libpfm-python3.patch
- Build the python parts using singlespec macros to allow switching
  as needed
* Wed Jan 17 2018 tchvatal@suse.com
- Update to 4.9.0:
  * Intel Broadwell EP uncore PMUs support (all PMU boxes)
  * AMD Fam17h (Zen) core PMU support
  * IBM Power9 core PMU support
  * AMD Fam16h (Jaguar) support
  * various event table updates
  * various bug fixes
- Drop upstream merged patches:
  * libpfm_add-power9-entries-to-validate_power-c.patch
  * libpfm_enable-ibm-power9-core-pmu-support-beta.patch
  * libpfm_fix-power9-event-file-header.patch
  * libpfm_power9-event-list-update-for-perfmon2.patch
* Wed Aug 16 2017 tonyj@suse.com
- Add Power9 support (FATE#322257)
  New patch: libpfm_enable-ibm-power9-core-pmu-support-beta.patch
  New patch: libpfm_fix-power9-event-file-header.patch
  New patch: libpfm_power9-event-list-update-for-perfmon2.patch
  New patch: libpfm_add-power9-entries-to-validate_power-c.patch
* Sat Jan 14 2017 mpluskal@suse.com
- Cleanup spec file
* Tue Dec 27 2016 adam.majer@suse.de
- Version bump to 4.8.0:
  * Intel Knights Landing support (core and uncore)
  * Intel Goldmont support
  * Allow . as a delimiter for event string
  * enable Broadwell EP
  * Intel event table updates
  * various bug fixes
- Requires swig 2.0.5 to compile since older versions cannot
  parse long long types in enum value assignments.
* Fri Jun 17 2016 tchvatal@suse.com
- Version bump to 4.7.0:
  * Intel Skylake core PMU
  * Intel Haswell-EP uncore PMUs
  * Intel Broadwell-DE
  * Major update on Intel event tables
  * bug fixes and many other improvements
- Respect cflags, disable werror bnc#985166
* Tue Jan 19 2016 tonyj@suse.com
- Package useful utilities (check_events. evt2raw and showevtinfo)
  in devel package.
* Fri Mar 13 2015 tchvatal@suse.com
- Version bump to 4.6.0 fate#318068:
  * Intel Broadwell (desktop core)
  * Intel Haswell-EP (core)
  * Applied Micro X-Gene processor
  * ARM A53 processor
  * Intel SNB, IVB, HSW event table updates
  * IBM Power8 event table updates
  * improved Intel x86 model detection
  * bug fixes and many other improvements
- Cleanup with spec-cleaner
- Drop obsolete patch:
  * libpfm-add-ibm-power8-support.patch
- Remove with_python switch that always evaluated as true
  * If the need is really here it should be used as %%bcond_without
* Mon Feb 16 2015 p.drouand@gmail.com
- Update to version 4.5.0
  * Intel IVB-EP uncore PMU support
  * Intel Silvermont support
  * Perf raw event syntax support
  * Intel RAPL event support
  * AMD Fam15h northbridge support
  * Qualcomm Krait support
  * IBM Power 8 support
  * IBM s390 updates
  * AMD Fam15h fixes
  * various IVB, SNB, HSW event table updates
  * more bug fixes
* Thu Jan  9 2014 tonyj@suse.com
- Add Power8 support (libpfm-add-ibm-power8-support.patch) FATE#315274
* Wed Dec  4 2013 tonyj@suse.com
- Update to version 4.4.
- Changelog:
  - Intel SandyBridge-EP uncore PMU support (all boxes)
  - Intel IvyBridge desktop core and uncore PMU support
  - Intel IvyBridge-EP core PMU support
  - newer Intel Haswell desktop core PMU support
  - newer Intel Atom
  - Intel Knigts Corner
  - Intel Nehalem, Westmere, SandyBridge, IvyBridge, Haswell PEBS Load Latency
    modifier (ldlat)
  - many bug fixes and other minor improvements
* Mon Jan 28 2013 dimstar@opensuse.org
- Add baselibs.conf: provide libpfm4 as -32bit (makes papi-32bit
  installable).
* Wed Jan  9 2013 pth@suse.de
- Run service to format spec file.
- Small cosmetic changes in spec file.
* Tue Jan  8 2013 tonyj@suse.com
- Changes to python builds, drop duplicate defns already in system macros.
- Fix build when with_python=0
* Fri Jan  4 2013 jengelh@inai.de
- Parallel build, remove redundant %%clean section, consistent use
  of %%buildroot
- Follow python package naming guidelines
- Separate out static library into distinct subpackage
* Sat Dec 29 2012 tonyj@suse.com
- Initial checkin of libpfm4 (version 4.3).
